@@ -26,6 +26,7 @@ def inputData(self, ScriptType: str = None):
         '19 = MEX Oropeza Temperate': [[80, 90], [0, 1, 2, 3]],
         '20 = MEX Oropeza HumTropic': [[80, 90], [0, 1, 2, 3]],
         '21 = CHL Perez-Fargallo': [[80, 90], [2, 3]],
+        '22 = INT ISO7730': [[1, 2, 3], [0]],
 
     }
 
@@ -60,7 +61,7 @@ def inputData(self, ScriptType: str = None):
                 90: 'ASHRAE 55 90% acceptability',
             },
             'ComfMod': {
-                0: 'ASHRAE 55 Static setpoints (calculated with Clima Tool)',
+                0: 'ISO 7730 Static setpoints',
                 1: 'ASHRAE 55 Adaptive setpoints when applicable, otherwise CTE',
                 2: 'ASHRAE 55 Adaptive setpoints when applicable, otherwise ISO 7730 Static setpoints',
                 3: 'ASHRAE 55 Adaptive setpoints when applicable, otherwise ASHRAE 55 Adaptive setpoints horizontally extended',
@@ -329,7 +330,17 @@ def inputData(self, ScriptType: str = None):
                 3: 'Perez-Fargallo Model Adaptive setpoints when applicable, otherwise Adaptive setpoints horizontally extended',
             }
         },
-
+        22: {
+            'name': '22 = INT ISO7730',
+            'CAT': {
+                1: 'Cat A: -0.2 < PMV < 0.2; PPD < 6%',
+                2: 'Cat B: -0.5 < PMV < 0.5; PPD < 10%',
+                3: 'Cat C: -0.7 < PMV < 0.7; PPD < 15%',
+            },
+            'ComfMod': {
+                0: 'ISO 7730 Static setpoints',
+            }
+        },
     }
 
     print('The information you will be required to enter below will be used to generate the customised output IDFs:')
@@ -358,6 +369,7 @@ def inputData(self, ScriptType: str = None):
         '19 = MEX Oropeza Temperate;\n'
         '20 = MEX Oropeza HumTropic;\n'
         '21 = CHL Perez-Fargallo;\n'
+        '22 = INT ISO7730;\n'
         'Please refer to the full list of setpoint temperatures at https://raw.githack.com/dsanchez-garcia/accim/master/docs/full_setpoint_table.html\n'
         '): '
     ).split())
@@ -381,9 +393,9 @@ def inputData(self, ScriptType: str = None):
     fullCATlist = [1, 2, 3, 80, 85, 90]
     self.CAT_List = list(int(num) for num in input(
         "Enter the Category numbers separated by space (\n"
-        "1 = CAT I;\n"
-        "2 = CAT II;\n"
-        "3 = CAT III;\n"
+        "1 = CAT I / CAT A;\n"
+        "2 = CAT II / CAT B;\n"
+        "3 = CAT III / CAT C;\n"
         "80 = 80% ACCEPT;\n"
         "85 = 85% ACCEPT;\n"
         "90 = 90% ACCEPT;\n"
@@ -406,8 +418,8 @@ def inputData(self, ScriptType: str = None):
     fullComfModList = [0, 0.1, 0.2, 0.3, 0.4, 0.5, 1, 1.1, 1.2, 1.3, 1.4, 1.5, 2, 3]
     self.ComfMod_List = list(float(num) for num in input(
         "Enter the Comfort Mode numbers separated by space (\n"
-        # "0 = Static;\n"
-        # "1, 2, 3 = Adaptive;\n"
+        "0 or 0.X = Static;\n"
+        "1, 1.X, 2, 3 = Adaptive;\n"
         "Please refer to the full list of setpoint temperatures at https://raw.githack.com/dsanchez-garcia/accim/master/docs/full_setpoint_table.html\n"
         "): ").split())
     while len(self.ComfMod_List) == 0 or not all(elem in fullComfModList for elem in self.ComfMod_List):
@@ -422,6 +434,100 @@ def inputData(self, ScriptType: str = None):
             self.ComfMod_List = list(
                 float(num) for num in input("     Enter the Comfort Mode numbers separated by space: ").split())
 
+    self.SetpointAcc = float(input('\nEnter the setpoint accuracy number (any number greater than 0): '))
+    while self.SetpointAcc < 0:
+        print('          The setpoint accuracy number is not correct. It must be a number greater than 0. Please enter the number again.')
+        self.SetpointAcc = float(input('         Enter the setpoint accuracy number (any number greater than 0): '))
+    while input('          Are you sure the number is correct? [y or [] / n]: ') == 'n':
+        self.SetpointAcc = float(input('      Enter the setpoint accuracy number (any number greater than 0): '))
+        while self.SetpointAcc < 0 or self.SetpointAcc > 1:
+            print('          The setpoint accuracy number is not correct. It must be a number greater than 0. Please enter the number again.')
+            self.SetpointAcc = float(input('         Enter the setpoint accuracy number (any number greater than 0): '))
+
+    if (any(i in [1, 2] for i in self.ComfStand_List) and 0 in self.ComfMod_List) or 22 in self.ComfStand_List:
+        self.CoolSeasonStart = list(
+            int(num)
+            for num
+            in input("\nEnter the start of the cooling season in numeric date format dd/mm or the day of the year: ").split('/')
+        )
+        if len(self.CoolSeasonStart) == 1:
+            day_of_year = self.CoolSeasonStart[0]
+        elif len(self.CoolSeasonStart) == 2:
+            from datetime import date
+            day_of_year = date(2007, self.CoolSeasonStart[1], self.CoolSeasonStart[0]).timetuple().tm_yday
+        while day_of_year < 1 or day_of_year > 365:
+            print('          The start for cooling season is not correct. It must be a numeric date format dd/mm or the day of the year. Please enter the value again.')
+            self.CoolSeasonStart = list(
+                int(num)
+                for num
+                in input("Enter the start of the cooling season in numeric date format dd/mm or the day of the year: ").split('/')
+            )
+        while input('          Are you sure the number is correct? [y or [] / n]: ') == 'n':
+            self.CoolSeasonStart = list(
+                int(num)
+                for num
+                in input("Enter the start of the cooling season in numeric date format dd/mm or the day of the year: ").split('/')
+            )
+            if len(self.CoolSeasonStart) == 1:
+                day_of_year = self.CoolSeasonStart[0]
+            elif len(self.CoolSeasonStart) == 2:
+                day_of_year = date(2007, self.CoolSeasonStart[1], self.CoolSeasonStart[0]).timetuple().tm_yday
+            while day_of_year < 1 or day_of_year > 365:
+                print('          The start for cooling season is not correct. It must be a numeric date format dd/mm or the day of the year. Please enter the value again.')
+                self.CoolSeasonStart = list(
+                    int(num)
+                    for num
+                    in input("Enter the start of the cooling season in numeric date format dd/mm or the day of the year: ").split('/')
+                )
+                if len(self.CoolSeasonStart) == 1:
+                    day_of_year = self.CoolSeasonStart[0]
+                elif len(self.CoolSeasonStart) == 2:
+                    day_of_year = date(2007, self.CoolSeasonStart[1], self.CoolSeasonStart[0]).timetuple().tm_yday
+        self.CoolSeasonStart = day_of_year
+
+        self.CoolSeasonEnd = list(
+            int(num)
+            for num
+            in input("\nEnter the end of the cooling season in numeric date format dd/mm or the day of the year: ").split('/')
+        )
+        if len(self.CoolSeasonEnd) == 1:
+            day_of_year = self.CoolSeasonEnd[0]
+        elif len(self.CoolSeasonEnd) == 2:
+            from datetime import date
+            day_of_year = date(2007, self.CoolSeasonEnd[1], self.CoolSeasonEnd[0]).timetuple().tm_yday
+        while day_of_year < 1 or day_of_year > 365:
+            print('          The end for cooling season is not correct. It must be a numeric date format dd/mm or the day of the year. Please enter the value again.')
+            self.CoolSeasonEnd = list(
+                int(num)
+                for num
+                in input("Enter the end of the cooling season in numeric date format dd/mm or the day of the year: ").split('/')
+            )
+        while input('          Are you sure the number is correct? [y or [] / n]: ') == 'n':
+            self.CoolSeasonEnd = list(
+                int(num)
+                for num
+                in input("Enter the end of the cooling season in numeric date format dd/mm or the day of the year: ").split('/')
+            )
+            if len(self.CoolSeasonEnd) == 1:
+                day_of_year = self.CoolSeasonEnd[0]
+            elif len(self.CoolSeasonEnd) == 2:
+                day_of_year = date(2007, self.CoolSeasonEnd[1], self.CoolSeasonEnd[0]).timetuple().tm_yday
+            while day_of_year < 1 or day_of_year > 365:
+                print('          The end for cooling season is not correct. It must be a numeric date format dd/mm or the day of the year. Please enter the value again.')
+                self.CoolSeasonEnd = list(
+                    int(num)
+                    for num
+                    in input("Enter the end of the cooling season in numeric date format dd/mm or the day of the year: ").split('/')
+                )
+                if len(self.CoolSeasonEnd) == 1:
+                    day_of_year = self.CoolSeasonEnd[0]
+                elif len(self.CoolSeasonEnd) == 2:
+                    day_of_year = date(2007, self.CoolSeasonEnd[1], self.CoolSeasonEnd[0]).timetuple().tm_yday
+        self.CoolSeasonEnd = day_of_year
+    else:
+        self.CoolSeasonStart = 121
+        self.CoolSeasonEnd = 274
+
     if 'mm' in ScriptType.lower():
         fullHVACmodeList = [0, 1, 2]
         self.HVACmode_List = list(int(num) for num in input(
@@ -518,6 +624,10 @@ def inputData(self, ScriptType: str = None):
                 while self.MultiplierVOF < 0 or self.MultiplierVOF > 1:
                     print('          The multiplier number is not correct. It must be a number between 0 and 1. Please enter the number again.')
                     self.MultiplierVOF = float(input('         Enter the multiplier number for modulating the Ventilation Opening Factor (any number between 0 and 1): '))
+        else:
+            self.MaxTempDiffVOF = 20
+            self.MinTempDiffVOF = 0.5
+            self.MultiplierVOF = 0.25
 
         self.VSToffset_List = list(float(num) for num in input(
             "\nEnter the VSToffset numbers separated by space (if omitted, will be 0): ").split())
@@ -588,6 +698,26 @@ def inputData(self, ScriptType: str = None):
         except ValueError:
             self.ASTtol_value_steps = float(0.1)
 
+    self.user_input_arguments = {
+        'ComfStand': self.ComfStand_List,
+        'CAT': self.CAT_List,
+        'ComfMod': self.ComfMod_List,
+        'SetpointAcc': self.SetpointAcc,
+        'CoolSeasonStart': self.CoolSeasonStart,
+        'CoolSeasonEnd': self.CoolSeasonEnd,
+        'HVACmode': self.HVACmode_List,
+        'VentCtrl': self.VentCtrl_List,
+        'MaxTempDiffVOF': self.MaxTempDiffVOF,
+        'MinTempDiffVOF': self.MinTempDiffVOF,
+        'MultiplierVOF': self.MultiplierVOF,
+        'VSToffset': self.VSToffset_List,
+        'MinOToffset': self.MinOToffset_List,
+        'MaxWindSpeed': self.MaxWindSpeed_List,
+        'ASTtol_start': self.ASTtol_value_from,
+        'ASTtol_end_input': self.ASTtol_value_to_input,
+        'ASTtol_steps': self.ASTtol_value_steps,
+    }
+
 
 def genIDF(self,
            ScriptType: str = None,
@@ -595,6 +725,9 @@ def genIDF(self,
            ComfStand=None,
            CAT=None,
            ComfMod=None,
+           SetpointAcc=10000,
+           CoolSeasonStart=121,
+           CoolSeasonEnd=274,
            HVACmode=None,
            VentCtrl=None,
            MaxTempDiffVOF=20,
@@ -622,6 +755,9 @@ def genIDF(self,
     arguments = (ComfStand is None,
                  CAT is None,
                  ComfMod is None,
+                 SetpointAcc == 10000,
+                 CoolSeasonStart == 121,
+                 CoolSeasonEnd == 274,
                  HVACmode is None,
                  VentCtrl is None,
                  MaxTempDiffVOF == 20,
@@ -646,6 +782,32 @@ def genIDF(self,
         self.ComfStand_List = ComfStand
         self.CAT_List = CAT
         self.ComfMod_List = ComfMod
+        self.SetpointAcc = SetpointAcc
+        
+        if type(CoolSeasonStart) is str:
+            CoolSeasonStart = list(int(num) for num in CoolSeasonStart.split('/'))
+            from datetime import date
+            day_of_year = date(2007, CoolSeasonStart[1], CoolSeasonStart[0]).timetuple().tm_yday
+        elif type(CoolSeasonStart) is int:
+            day_of_year = CoolSeasonStart
+        self.CoolSeasonStart = day_of_year
+        
+        # CoolSeasonEnd = list(int(num) for num in CoolSeasonEnd.split('/'))
+        # if len(CoolSeasonEnd) == 1:
+        #     day_of_year = CoolSeasonEnd[0]
+        # elif len(CoolSeasonEnd) == 2:
+        #     from datetime import date
+        #     day_of_year = date(2007, CoolSeasonEnd[1], CoolSeasonEnd[0]).timetuple().tm_yday
+        # self.CoolSeasonEnd = day_of_year
+        if type(CoolSeasonEnd) is str:
+            CoolSeasonEnd = list(int(num) for num in CoolSeasonEnd.split('/'))
+            from datetime import date
+            day_of_year = date(2007, CoolSeasonEnd[1], CoolSeasonEnd[0]).timetuple().tm_yday
+        elif type(CoolSeasonEnd) is int:
+            day_of_year = CoolSeasonEnd
+        self.CoolSeasonEnd = day_of_year
+
+        
         self.HVACmode_List = HVACmode
         self.VentCtrl_List = VentCtrl
         self.MaxTempDiffVOF = MaxTempDiffVOF,
@@ -713,6 +875,7 @@ def genIDF(self,
         19: '[CS_MEX Oropeza Temperate',
         20: '[CS_MEX Oropeza HumTropic',
         21: '[CS_CHL Perez-Fargallo',
+        22: '[CS_INT ISO7730',
     }
 
     outputlist = []
@@ -768,9 +931,9 @@ def genIDF(self,
                                                             + '.idf'
                                                     )
                                                     outputlist.append(outputname)
-                elif ComfStand_value in [1, 4, 5]:
+                elif ComfStand_value in [1, 4, 5, 22]:
                     for CAT_value in self.CAT_List:
-                        if ComfStand_value in [1] and CAT_value not in range(0, 4):
+                        if ComfStand_value in [1, 22] and CAT_value not in range(0, 4):
                             continue
                         elif ComfStand_value in [4, 5] and CAT_value not in [1, 2]:
                             continue
@@ -778,6 +941,8 @@ def genIDF(self,
                             for ComfMod_value in self.ComfMod_List:
                                 if ComfStand_value not in [13, 14] and ComfMod_value in [0.1, 0.2, 0.3, 0.4, 0.5, 1.1, 1.2, 1.3, 1.4, 1.5]:
                                     continue
+                                elif ComfStand_value == 22 and ComfMod_value != 0:
+                                    continue
                                 else:
                                     for HVACmode_value in self.HVACmode_List:
                                         if HVACmode_value == 0:
@@ -839,6 +1004,8 @@ def genIDF(self,
                                     continue
                                 elif ComfStand_value not in [13, 14] and ComfMod_value in [0.1, 0.2, 0.3, 0.4, 0.5, 1.1, 1.2, 1.3, 1.4, 1.5]:
                                     continue
+                                elif ComfStand_value == 21 and ComfMod_value not in [2, 3]:
+                                    continue
                                 else:
                                     for HVACmode_value in self.HVACmode_List:
                                         if HVACmode_value == 0:
@@ -920,6 +1087,7 @@ def genIDF(self,
         if verboseMode:
             print('Generating the following output IDF files:')
         # pbar = tqdm(total=len(outputlist))
+        # self.output_idf_dict = {}
         for file in filelist_pymod:
             filename = file
 
@@ -935,6 +1103,8 @@ def genIDF(self,
                              program.Name == 'SetInputData'])
             SetVOFinputData = ([program for program in idf1.idfobjects['EnergyManagementSystem:Program'] if
                              program.Name == 'SetVOFinputData'])
+            SetAST = ([program for program in idf1.idfobjects['EnergyManagementSystem:Program'] if
+                             program.Name == 'SetAST'])
             if TempCtrl.lower() == 'temp' or TempCtrl.lower() == 'temperature':
                 for ComfStand_value in self.ComfStand_List:
                     SetInputData[0].Program_Line_1 = 'set ComfStand = ' + repr(ComfStand_value)
@@ -948,6 +1118,9 @@ def genIDF(self,
                                                                  self.ASTtol_value_steps):
                                     SetInputData[0].Program_Line_9 = 'set ACSTtol = ' + repr(-ASTtol_value)
                                     SetInputData[0].Program_Line_10 = 'set AHSTtol = ' + repr(ASTtol_value)
+                                    SetInputData[0].Program_Line_11 = 'set CoolSeasonStart = ' + repr(self.CoolSeasonStart)
+                                    SetInputData[0].Program_Line_12 = 'set CoolSeasonEnd = ' + repr(self.CoolSeasonEnd)
+                                    SetAST[0].Program_Line_1 = 'set SetpointAcc = ' + repr(self.SetpointAcc)
                                     outputname = (
                                             filename
                                             + ComfStand_dict[ComfStand_value]
@@ -967,6 +1140,7 @@ def genIDF(self,
                                         # time.sleep(0.1)
                                         # pbar.update(1)
                                     idf1.savecopy(outputname)
+                                    self.output_idf_dict.update({outputname: idf1})
                             else:
                                 for VentCtrl_value in self.VentCtrl_List:
                                     SetInputData[0].Program_Line_5 = 'set VentCtrl = ' + repr(VentCtrl_value)
@@ -986,10 +1160,11 @@ def genIDF(self,
                                                 for ASTtol_value in numpy.arange(self.ASTtol_value_from,
                                                                                  self.ASTtol_value_to,
                                                                                  self.ASTtol_value_steps):
-                                                    SetInputData[0].Program_Line_9 = 'set ACSTtol = ' + repr(
-                                                        -ASTtol_value)
-                                                    SetInputData[0].Program_Line_10 = 'set AHSTtol = ' + repr(
-                                                        ASTtol_value)
+                                                    SetInputData[0].Program_Line_9 = 'set ACSTtol = ' + repr(-ASTtol_value)
+                                                    SetInputData[0].Program_Line_10 = 'set AHSTtol = ' + repr(ASTtol_value)
+                                                    SetInputData[0].Program_Line_11 = 'set CoolSeasonStart = ' + repr(self.CoolSeasonStart)
+                                                    SetInputData[0].Program_Line_12 = 'set CoolSeasonEnd = ' + repr(self.CoolSeasonEnd)
+                                                    SetAST[0].Program_Line_1 = 'set SetpointAcc = ' + repr(self.SetpointAcc)
                                                     outputname = (
                                                             filename
                                                             + ComfStand_dict[ComfStand_value]
@@ -1009,9 +1184,10 @@ def genIDF(self,
                                                         # time.sleep(0.1)
                                                         # pbar.update(1)
                                                     idf1.savecopy(outputname)
-                    elif ComfStand_value in [1, 4, 5]:
+                                                    self.output_idf_dict.update({outputname: idf1})
+                    elif ComfStand_value in [1, 4, 5, 22]:
                         for CAT_value in self.CAT_List:
-                            if ComfStand_value in [1] and CAT_value not in range(0, 4):
+                            if ComfStand_value in [1, 22] and CAT_value not in range(0, 4):
                                 continue
                             elif ComfStand_value in [4, 5] and CAT_value not in [1, 2]:
                                 continue
@@ -1020,6 +1196,8 @@ def genIDF(self,
                                 for ComfMod_value in self.ComfMod_List:
                                     if ComfStand_value not in [13, 14] and ComfMod_value in [0.1, 0.2, 0.3, 0.4, 0.5, 1.1, 1.2, 1.3, 1.4, 1.5]:
                                         continue
+                                    elif ComfStand_value == 22 and ComfMod_value != 0:
+                                        continue
                                     else:
                                         SetInputData[0].Program_Line_3 = 'set ComfMod = ' + repr(ComfMod_value)
                                         for HVACmode_value in self.HVACmode_List:
@@ -1030,6 +1208,9 @@ def genIDF(self,
                                                                                  self.ASTtol_value_steps):
                                                     SetInputData[0].Program_Line_9 = 'set ACSTtol = ' + repr(-ASTtol_value)
                                                     SetInputData[0].Program_Line_10 = 'set AHSTtol = ' + repr(ASTtol_value)
+                                                    SetInputData[0].Program_Line_11 = 'set CoolSeasonStart = ' + repr(self.CoolSeasonStart)
+                                                    SetInputData[0].Program_Line_12 = 'set CoolSeasonEnd = ' + repr(self.CoolSeasonEnd)
+                                                    SetAST[0].Program_Line_1 = 'set SetpointAcc = ' + repr(self.SetpointAcc)
                                                     outputname = (
                                                             filename
                                                             + ComfStand_dict[ComfStand_value]
@@ -1049,6 +1230,7 @@ def genIDF(self,
                                                         # time.sleep(0.1)
                                                         # pbar.update(1)
                                                     idf1.savecopy(outputname)
+                                                    self.output_idf_dict.update({outputname: idf1})
                                             else:
                                                 for VentCtrl_value in self.VentCtrl_List:
                                                     SetInputData[0].Program_Line_5 = 'set VentCtrl = ' + repr(VentCtrl_value)
@@ -1070,12 +1252,11 @@ def genIDF(self,
                                                                 for ASTtol_value in numpy.arange(self.ASTtol_value_from,
                                                                                                  self.ASTtol_value_to,
                                                                                                  self.ASTtol_value_steps):
-                                                                    SetInputData[
-                                                                        0].Program_Line_9 = 'set ACSTtol = ' + repr(
-                                                                        -ASTtol_value)
-                                                                    SetInputData[
-                                                                        0].Program_Line_10 = 'set AHSTtol = ' + repr(
-                                                                        ASTtol_value)
+                                                                    SetInputData[0].Program_Line_9 = 'set ACSTtol = ' + repr(-ASTtol_value)
+                                                                    SetInputData[0].Program_Line_10 = 'set AHSTtol = ' + repr(ASTtol_value)
+                                                                    SetInputData[0].Program_Line_11 = 'set CoolSeasonStart = ' + repr(self.CoolSeasonStart)
+                                                                    SetInputData[0].Program_Line_12 = 'set CoolSeasonEnd = ' + repr(self.CoolSeasonEnd)
+                                                                    SetAST[0].Program_Line_1 = 'set SetpointAcc = ' + repr(self.SetpointAcc)
                                                                     outputname = (
                                                                             filename
                                                                             + ComfStand_dict[ComfStand_value]
@@ -1095,6 +1276,7 @@ def genIDF(self,
                                                                         # time.sleep(0.1)
                                                                         # pbar.update(1)
                                                                     idf1.savecopy(outputname)
+                                                                    self.output_idf_dict.update({outputname: idf1})
                     elif ComfStand_value in [2, 3, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21]:
                         for CAT_value in self.CAT_List:
                             if ComfStand_value in [2, 3, 6, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
@@ -1109,6 +1291,8 @@ def genIDF(self,
                                         continue
                                     elif ComfStand_value not in [13, 14] and ComfMod_value in [0.1, 0.2, 0.3, 0.4, 0.5, 1.1, 1.2, 1.3, 1.4, 1.5]:
                                         continue
+                                    elif ComfStand_value == 21 and ComfMod_value not in [2, 3]:
+                                        continue
                                     else:
                                         SetInputData[0].Program_Line_3 = 'set ComfMod = ' + repr(ComfMod_value)
                                         for HVACmode_value in self.HVACmode_List:
@@ -1119,6 +1303,9 @@ def genIDF(self,
                                                                                  self.ASTtol_value_steps):
                                                     SetInputData[0].Program_Line_9 = 'set ACSTtol = ' + repr(-ASTtol_value)
                                                     SetInputData[0].Program_Line_10 = 'set AHSTtol = ' + repr(ASTtol_value)
+                                                    SetInputData[0].Program_Line_11 = 'set CoolSeasonStart = ' + repr(self.CoolSeasonStart)
+                                                    SetInputData[0].Program_Line_12 = 'set CoolSeasonEnd = ' + repr(self.CoolSeasonEnd)
+                                                    SetAST[0].Program_Line_1 = 'set SetpointAcc = ' + repr(self.SetpointAcc)
                                                     outputname = (
                                                             filename
                                                             + ComfStand_dict[ComfStand_value]
@@ -1138,6 +1325,7 @@ def genIDF(self,
                                                         # time.sleep(0.1)
                                                         # pbar.update(1)
                                                     idf1.savecopy(outputname)
+                                                    self.output_idf_dict.update({outputname: idf1})
                                             else:
                                                 for VentCtrl_value in self.VentCtrl_List:
                                                     SetInputData[0].Program_Line_5 = 'set VentCtrl = ' + repr(VentCtrl_value)
@@ -1159,6 +1347,9 @@ def genIDF(self,
                                                                                                  self.ASTtol_value_steps):
                                                                     SetInputData[0].Program_Line_9 = 'set ACSTtol = ' + repr(-ASTtol_value)
                                                                     SetInputData[0].Program_Line_10 = 'set AHSTtol = ' + repr(ASTtol_value)
+                                                                    SetInputData[0].Program_Line_11 = 'set CoolSeasonStart = ' + repr(self.CoolSeasonStart)
+                                                                    SetInputData[0].Program_Line_12 = 'set CoolSeasonEnd = ' + repr(self.CoolSeasonEnd)
+                                                                    SetAST[0].Program_Line_1 = 'set SetpointAcc = ' + repr(self.SetpointAcc)
                                                                     outputname = (
                                                                             filename
                                                                             + ComfStand_dict[ComfStand_value]
@@ -1178,6 +1369,7 @@ def genIDF(self,
                                                                         # time.sleep(0.1)
                                                                         # pbar.update(1)
                                                                     idf1.savecopy(outputname)
+                                                                    self.output_idf_dict.update({outputname: idf1})
             elif TempCtrl.lower() == 'pmv':
                 SetInputData[0].Program_Line_4 = 'set HVACmode = 0'
                 outputname = (
@@ -1199,7 +1391,7 @@ def genIDF(self,
                     # time.sleep(0.1)
                     # pbar.update(1)
                 idf1.savecopy(outputname)
-
+                self.output_idf_dict.update({outputname: idf1})
         # pbar.close()
     elif confirmGen == False:
         if verboseMode:
