@@ -24,7 +24,10 @@ class accimJob():
         addOutputVariablesSimplified, \
         addOutputVariablesDetailed, \
         removeExistingOutputVariables, \
-        removeDuplicatedOutputVariables
+        removeDuplicatedOutputVariables, \
+        outputsSpecified, \
+        genOutputDataframe, \
+        takeOutputDataFrame
 
     from accim.sim.accim_ExistingHVAC import \
         addForscriptSchExistHVAC
@@ -69,15 +72,20 @@ class accimJob():
             iddfile = 'C:\EnergyPlusV22-1-0\Energy+.idd'
         elif EnergyPlus_version.lower() == '22.2':
             iddfile = 'C:\EnergyPlusV22-2-0\Energy+.idd'
+        elif EnergyPlus_version.lower() == '23.1':
+            iddfile = 'C:\EnergyPlusV23-1-0\Energy+.idd'
         else:
             raise ValueError("""EnergyPlus version not supported.\n
-                                     Only works for versions between EnergyPlus 9.1 (enter 9.1) and EnergyPlus 22.2 (enter 22.2)""")
+                                     Only works for versions between EnergyPlus 9.1 (enter 9.1) and EnergyPlus 23.1 (enter 23.1)""")
         if verboseMode:
             print('IDD location is: '+iddfile)
         IDF.setiddname(iddfile)
 
+
+
         fname1 = filename_temp+'.idf'
         self.idf0 = IDF(fname1)
+
         self.idf0.savecopy(filename_temp+'_pymod.idf')
 
         self.filename = filename_temp+'_pymod'
@@ -85,6 +93,8 @@ class accimJob():
         self.idf1 = IDF(fname1)
         self.filename = filename_temp+'_pymod'
 
+        self.output_idf_dict = {}
+
         # print(self.filename)
         self.occupiedZones_orig = []
 
